@@ -39,6 +39,18 @@
 #include <string.h>
 #endif
 
+#if TEST_LIBCOMPAT || !defined(HAVE_FGETPWENT) || !defined(HAVE_FGETGRENT)
+#include <stdio.h>
+#endif
+
+#if TEST_LIBCOMPAT || !defined(HAVE_FGETPWENT)
+#include <pwd.h>
+#endif
+
+#if TEST_LIBCOMPAT || !defined(HAVE_FGETGRENT)
+#include <grp.h>
+#endif
+
 /* Language definitions. */
 
 /* Supported since gcc 5.1.0 and clang 2.9.0. For attributes that appeared
@@ -59,10 +71,12 @@
 
 #if LIBCOMPAT_GCC_VERSION >= 0x0300 || __has_attribute(__format__)
 #define LIBCOMPAT_ATTR_FMT(t, f, a)	__attribute__((__format__(t, f, a)))
+#define LIBCOMPAT_ATTR_FMT_ARG(n)	__attribute__((__format_arg__(n)))
 #define LIBCOMPAT_ATTR_PRINTF(n)	LIBCOMPAT_ATTR_FMT(__printf__, n, n + 1)
 #define LIBCOMPAT_ATTR_VPRINTF(n)	LIBCOMPAT_ATTR_FMT(__printf__, n, 0)
 #else
 #define LIBCOMPAT_ATTR_FMT(t, f, a)
+#define LIBCOMPAT_ATTR_FMT_ARG(n)
 #define LIBCOMPAT_ATTR_PRINTF(n)
 #define LIBCOMPAT_ATTR_VPRINTF(n)
 #endif
@@ -137,6 +151,10 @@ extern "C" {
 #define strerror test_strerror
 #undef strsignal
 #define strsignal test_strsignal
+#undef fgetpwent
+#define fgetpwent test_fgetpwent
+#undef fgetgrent
+#define fgetgrent test_fgetgrent
 #undef scandir
 #define scandir test_scandir
 #undef alphasort
@@ -150,52 +168,74 @@ extern const char *const sys_siglist[];
 #endif
 
 #if TEST_LIBCOMPAT || !defined(HAVE_C99_SNPRINTF)
-int snprintf(char *str, size_t n, char const *fmt, ...)
+int
+snprintf(char *str, size_t n, char const *fmt, ...)
 	LIBCOMPAT_ATTR_PRINTF(3);
-int vsnprintf(char *buf, size_t maxsize, const char *fmt, va_list args)
+int
+vsnprintf(char *buf, size_t maxsize, const char *fmt, va_list args)
 	LIBCOMPAT_ATTR_VPRINTF(3);
 #endif
 
 #if TEST_LIBCOMPAT || !defined(HAVE_ASPRINTF)
-int asprintf(char **str, char const *fmt, ...)
+int
+asprintf(char **str, char const *fmt, ...)
 	LIBCOMPAT_ATTR_PRINTF(2);
-int vasprintf(char **str, const char *fmt, va_list args)
+int
+vasprintf(char **str, const char *fmt, va_list args)
 	LIBCOMPAT_ATTR_VPRINTF(2);
 #endif
 
 #if TEST_LIBCOMPAT || !defined(HAVE_STRCHRNUL)
-char *strchrnul(const char *s, int c);
+char *
+strchrnul(const char *s, int c);
 #endif
 
 #if TEST_LIBCOMPAT || !defined(HAVE_STRNLEN)
-size_t strnlen(const char *s, size_t n);
+size_t
+strnlen(const char *s, size_t n);
 #endif
 
 #if TEST_LIBCOMPAT || !defined(HAVE_STRNDUP)
-char *strndup(const char *s, size_t n);
+char *
+strndup(const char *s, size_t n);
 #endif
 
 #if TEST_LIBCOMPAT || !defined(HAVE_STRERROR)
-const char *strerror(int);
+const char *
+strerror(int);
 #endif
 
 #if TEST_LIBCOMPAT || !defined(HAVE_STRSIGNAL)
-const char *strsignal(int);
+const char *
+strsignal(int);
+#endif
+
+#if TEST_LIBCOMPAT || !defined(HAVE_FGETPWENT)
+struct passwd *
+fgetpwent(FILE *fp);
+#endif
+
+#if TEST_LIBCOMPAT || !defined(HAVE_FGETGRENT)
+struct group *
+fgetgrent(FILE *fp);
 #endif
 
 #if TEST_LIBCOMPAT || !defined(HAVE_SCANDIR)
 struct dirent;
-int scandir(const char *dir, struct dirent ***namelist,
-            int (*filter)(const struct dirent *),
-            int (*cmp)(const void *, const void *));
+int
+scandir(const char *dir, struct dirent ***namelist,
+        int (*filter)(const struct dirent *),
+        int (*cmp)(const void *, const void *));
 #endif
 
 #if TEST_LIBCOMPAT || !defined(HAVE_ALPHASORT)
-int alphasort(const void *a, const void *b);
+int
+alphasort(const void *a, const void *b);
 #endif
 
 #if TEST_LIBCOMPAT || !defined(HAVE_UNSETENV)
-int unsetenv(const char *x);
+int
+unsetenv(const char *x);
 #endif
 
 #ifdef __cplusplus
