@@ -44,12 +44,14 @@
  */
 void
 write_filehash_except(struct pkginfo *pkg, struct pkgbin *pkgbin,
-                      struct fsys_namenode_list *list, enum fsys_namenode_flags mask)
+                      struct fsys_namenode_list *list,
+                      enum fsys_namenode_flags mask)
 {
 	struct atomic_file *file;
 	const char *hashfile;
 
-	debug(dbg_general, "generating infodb hashfile");
+	debug(dbg_general, "generating infodb digest file for %s",
+	      pkgbin_name(pkg, pkgbin, pnaw_always));
 
 	if (pkg_infodb_has_file(pkg, &pkg->available, HASHFILE))
 		return;
@@ -60,7 +62,7 @@ write_filehash_except(struct pkginfo *pkg, struct pkgbin *pkgbin,
 	atomic_file_open(file);
 
 	for (; list; list = list->next) {
-		 struct fsys_namenode *namenode = list->namenode;
+		const struct fsys_namenode *namenode = list->namenode;
 
 		if (mask && (namenode->flags & mask))
 			continue;
@@ -121,11 +123,11 @@ parse_filehash_buffer(struct varbuf *buf,
 			ohshit(_("control file '%s' for package '%s' "
 			         "contains empty filename"), HASHFILE, pkgname);
 
-		debug(dbg_eachfiledetail, "load hash '%s' for filename '%s'",
+		debug(dbg_eachfiledetail, "load digest '%s' for filename '%s'",
 		      thisline, filename);
 
 		/* Add the file to the list. */
-		namenode = fsys_hash_find_node(filename, 0);
+		namenode = fsys_hash_find_node(filename, FHFF_NONE);
 		namenode->newhash = nfstrsave(thisline);
 	}
 }
