@@ -1,6 +1,6 @@
 /*
  * libdpkg - Debian packaging suite library routines
- * pkg-format.c - customizable package formatting
+ * pkg-format.g - customizable package formatting
  *
  * Copyright © 2001 Wichert Akkerman <wakkerma@debian.org>
  *
@@ -15,12 +15,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef LIBDPKG_PKG_FORMAT_H
 #define LIBDPKG_PKG_FORMAT_H
 
+#include <stdbool.h>
+
 #include <dpkg/macros.h>
 #include <dpkg/error.h>
 #include <dpkg/dpkg-db.h>
@@ -35,11 +37,19 @@ DPKG_BEGIN_DECLS
 
 struct pkg_format_node;
 
-struct pkg_format_node *pkg_format_parse(const char *fmt,
-                                         struct dpkg_error *err);
-void pkg_format_free(struct pkg_format_node *head);
-void pkg_format_show(const struct pkg_format_node *head,
-                     struct pkginfo *pkg, struct pkgbin *pkgbin);
+bool
+pkg_format_needs_db_fsys(const struct pkg_format_node *head);
+
+struct pkg_format_node *
+pkg_format_parse(const char *fmt, struct dpkg_error *err);
+void
+pkg_format_free(struct pkg_format_node *head);
+void
+pkg_format_print(struct varbuf *vb, const struct pkg_format_node *head,
+                 struct pkginfo *pkg, struct pkgbin *pkgbin);
+void
+pkg_format_show(const struct pkg_format_node *head,
+                struct pkginfo *pkg, struct pkgbin *pkgbin);
 
 /** @} */
 
