@@ -108,7 +108,7 @@ test_version_compare(void)
 	test_pass(dpkg_version_compare(&a, &b) < 0);
 	test_pass(dpkg_version_compare(&b, &a) > 0);
 
-	/* FIXME: Complete. */
+	/* TODO: Complete. */
 }
 
 static void
@@ -163,9 +163,6 @@ test_version_parse(void)
 	test_pass(parseversion(&a, "0:0", NULL) == 0);
 	test_pass(dpkg_version_compare(&a, &b) == 0);
 
-	test_pass(parseversion(&a, "0:0-", NULL) == 0);
-	test_pass(dpkg_version_compare(&a, &b) == 0);
-
 	b = DPKG_VERSION_OBJECT(0, "0", "0");
 	test_pass(parseversion(&a, "0:0-0", NULL) == 0);
 	test_pass(dpkg_version_compare(&a, &b) == 0);
@@ -239,6 +236,14 @@ test_version_parse(void)
 	test_fail(parseversion(&a, "0:", &err) == 0);
 	test_error(err);
 
+	/* Test empty epoch in version. */
+	test_fail(parseversion(&a, ":1.0", &err) == 0);
+	test_error(err);
+
+	/* Test empty revision in version. */
+	test_fail(parseversion(&a, "1.0-", &err) == 0);
+	test_error(err);
+
 	/* Test version with embedded spaces. */
 	test_fail(parseversion(&a, "0:0 0-1", &err) == 0);
 	test_error(err);
@@ -288,12 +293,12 @@ test_version_parse(void)
 	}
 	free(verstr);
 
-	/* FIXME: Complete. */
+	/* TODO: Complete. */
 }
 
 TEST_ENTRY(test)
 {
-	test_plan(194);
+	test_plan(196);
 
 	test_version_blank();
 	test_version_is_informative();
