@@ -2,7 +2,7 @@
  * libdpkg - Debian packaging suite library routines
  * utils.c - helper functions for dpkg
  *
- * Copyright © 1995, 2008 Ian Jackson <ian@chiark.greenend.org.uk>
+ * Copyright © 1995, 2008 Ian Jackson <ijackson@chiark.greenend.org.uk>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,14 +33,14 @@ fgets_checked(char *buf, size_t bufsz, FILE *f, const char *fn)
 
 	if (!fgets(buf, bufsz, f)) {
 		if (ferror(f))
-			ohshite(_("read error in '%.250s'"), fn);
+			ohshite(_("read error in '%s'"), fn);
 		return -1;
 	}
 	l = strlen(buf);
 	if (l == 0)
-		ohshit(_("fgets gave an empty string from '%.250s'"), fn);
+		ohshit(_("fgets gave an empty string from '%s'"), fn);
 	if (buf[--l] != '\n')
-		ohshit(_("too-long line or missing newline in '%.250s'"), fn);
+		ohshit(_("too-long line or missing newline in '%s'"), fn);
 	buf[l] = '\0';
 
 	return l;
@@ -52,7 +52,7 @@ fgets_must(char *buf, size_t bufsz, FILE *f, const char *fn)
 	int l = fgets_checked(buf, bufsz, f, fn);
 
 	if (l < 0)
-		ohshit(_("unexpected end of file reading '%.250s'"), fn);
+		ohshit(_("unexpected end of file reading '%s'"), fn);
 
 	return l;
 }
