@@ -14,12 +14,24 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-package Dpkg::File;
+=encoding utf8
 
-use strict;
-use warnings;
+=head1 NAME
+
+Dpkg::File - file handling
+
+=head1 DESCRIPTION
+
+This module provides file handling support functions.
+
+B<Note>: This is a private module, its API can change at any time.
+
+=cut
+
+package Dpkg::File 0.01;
+
+use v5.36;
 
-our $VERSION = '0.01';
 our @EXPORT = qw(
     file_slurp
     file_dump
@@ -76,4 +88,12 @@ sub file_touch {
     close $fh or syserr(g_('cannot write %s'), $file);
 }
 
+=head1 CHANGES
+
+=head2 Version 0.xx
+
+This is a private module.
+
+=cut
+
 1;
