@@ -18,12 +18,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-use strict;
-use warnings;
+use v5.36;
 
 use Dpkg ();
 use Dpkg::Arch qw(get_host_arch);
 use Dpkg::Package;
+use Dpkg::BuildAPI qw(get_build_api);
 use Dpkg::Shlibs qw(get_library_paths);
 use Dpkg::Shlibs::Objdump;
 use Dpkg::Shlibs::SymbolFile;
@@ -40,11 +40,13 @@ my $packagebuilddir = 'debian/tmp';
 my $sourceversion;
 my $stdout;
 my $oppackage;
-my $compare = 1; # Bail on missing symbols by default
+# Bail on missing symbols by default.
+my $compare = 1;
 my $quiet = 0;
 my $input;
 my $output;
-my $template_mode = 0; # non-template mode by default
+# Non-template mode by default.
+my $template_mode = 0;
 my $verbose_output = 0;
 my $debug = 0;
 my $host_arch = get_host_arch();
@@ -95,58 +97,59 @@ my @files;
 while (@ARGV) {
     $_ = shift(@ARGV);
     if (m/^-p/p) {
-	$oppackage = ${^POSTMATCH};
-	my $err = pkg_name_is_illegal($oppackage);
-	error(g_("illegal package name '%s': %s"), $oppackage, $err) if $err;
+        $oppackage = ${^POSTMATCH};
+        my $err = pkg_name_is_invalid($oppackage);
+        error(g_("invalid package name '%s': %s"), $oppackage, $err) if $err;
     } elsif (m/^-l(.*)$/) {
         Dpkg::Shlibs::add_library_dir($1);
     } elsif (m/^-c(\d)?$/) {
-	$compare = $1 // 1;
+        $compare = $1 // 1;
     } elsif (m/^-q$/) {
-	$quiet = 1;
+        $quiet = 1;
     } elsif (m/^-d$/) {
-	$debug = 1;
+        $debug = 1;
     } elsif (m/^-v(.+)$/) {
-	$sourceversion = $1;
+        $sourceversion = $1;
     } elsif (m/^-e(.+)$/) {
-	my $file = $1;
-	if (-e $file) {
-	    push @files, $file;
-	} else {
-	    my @to_add = glob($file);
-	    push @files, @to_add;
-	    warning(g_("pattern '%s' did not match any file"), $file)
-		unless scalar(@to_add);
-	}
+        my $file = $1;
+        if (-e $file) {
+            push @files, $file;
+        } else {
+            my @to_add = glob($file);
+            push @files, @to_add;
+            warning(g_("pattern '%s' did not match any file"), $file)
+                unless scalar(@to_add);
+        }
     } elsif (m/^-P(.+)$/) {
-	$packagebuilddir = $1;
-	$packagebuilddir =~ s{/+$}{};
+        $packagebuilddir = $1;
+        $packagebuilddir =~ s{/+$}{};
     } elsif (m/^-O$/) {
-	$stdout = 1;
+        $stdout = 1;
     } elsif (m/^-I(.+)$/) {
-	$input = $1;
+        $input = $1;
     } elsif (m/^-O(.+)$/) {
-	$output = $1;
+        $output = $1;
     } elsif (m/^-t$/) {
-	$template_mode = 1;
+        $template_mode = 1;
     } elsif (m/^-V$/) {
-	$verbose_output = 1;
+        $verbose_output = 1;
     } elsif (m/^-a(.+)$/) {
-	$host_arch = $1;
+        $host_arch = $1;
     } elsif (m/^-(?:\?|-help)$/) {
-	usage();
-	exit(0);
+        usage();
+        exit(0);
     } elsif (m/^--version$/) {
-	version();
-	exit(0);
+        version();
+        exit(0);
     } else {
-	usageerr(g_("unknown option '%s'"), $_);
+        usageerr(g_("unknown option '%s'"), $_);
     }
 }
 
 report_options(debug_level => $debug);
 
-umask 0022; # ensure sane default permissions for created files
+# Ensure sane default permissions for created files.
+umask 0o022;
 
 if (exists $ENV{DPKG_GENSYMBOLS_CHECK_LEVEL}) {
     $compare = $ENV{DPKG_GENSYMBOLS_CHECK_LEVEL};
@@ -156,105 +159,123 @@ if (not defined($sourceversion)) {
     my $changelog = changelog_parse();
     $sourceversion = $changelog->{'Version'};
 }
+my $control = Dpkg::Control::Info->new();
+# Initialize the build API level.
+get_build_api($control);
 if (not defined($oppackage)) {
-    my $control = Dpkg::Control::Info->new();
     my @packages = map { $_->{'Package'} } $control->get_packages();
     if (@packages == 0) {
-	error(g_('no package stanza found in control info'));
+        error(g_('no package stanza found in control info'));
     } elsif (@packages > 1) {
-	error(g_('must specify package since control info has many (%s)'),
-	      "@packages");
+        error(g_('must specify package since control info has many (%s)'),
+              "@packages");
     }
     $oppackage = $packages[0];
 }
 
-my $symfile = Dpkg::Shlibs::SymbolFile->new(arch => $host_arch);
-my $ref_symfile = Dpkg::Shlibs::SymbolFile->new(arch => $host_arch);
-# Load source-provided symbol information
-foreach my $file ($input, $output, "debian/$oppackage.symbols.$host_arch",
-    "debian/symbols.$host_arch", "debian/$oppackage.symbols",
-    'debian/symbols')
-{
+my $symfile = Dpkg::Shlibs::SymbolFile->new(
+    arch => $host_arch,
+);
+my $ref_symfile = Dpkg::Shlibs::SymbolFile->new(
+    arch => $host_arch,
+);
+my @source_symbol_files = (
+    $input,
+    $output,
+    "debian/$oppackage.symbols.$host_arch",
+    "debian/symbols.$host_arch",
+    "debian/$oppackage.symbols",
+    'debian/symbols',
+);
+
+# Load source-provided symbol information.
+foreach my $file (@source_symbol_files) {
     if (defined $file and -e $file) {
-	debug(1, "Using references symbols from $file");
-	$symfile->load($file);
-	$ref_symfile->load($file) if $compare || ! $quiet;
-	last;
+        debug(1, "Using references symbols from $file");
+        $symfile->load($file);
+        $ref_symfile->load($file) if $compare || ! $quiet;
+        last;
     }
 }
 
-# Scan package build dir looking for libraries
+# Scan package build dir looking for libraries.
 if (not scalar @files) {
     PATH: foreach my $path (get_library_paths()) {
-	my $libdir = "$packagebuilddir$path";
-	$libdir =~ s{/+}{/}g;
-	lstat $libdir;
-	next if not -d _;
-	next if -l _; # Skip directories which are symlinks
-        # Skip any directory _below_ a symlink as well
+        my $libdir = "$packagebuilddir$path";
+        $libdir =~ s{/+}{/}g;
+        lstat $libdir;
+        next if not -d _;
+        # Skip directories which are symlinks.
+        next if -l _;
+        # Skip any directory _below_ a symlink as well.
         my $updir = $libdir;
         while (($updir =~ s{/[^/]*$}{}) and
                not check_files_are_the_same($packagebuilddir, $updir)) {
             next PATH if -l $updir;
         }
-	opendir(my $libdir_dh, "$libdir")
-	    or syserr(g_("can't read directory %s: %s"), $libdir, $!);
-	push @files, grep {
-	    /(\.so\.|\.so$)/ && -f &&
-	    Dpkg::Shlibs::Objdump::is_elf($_);
-	} map { "$libdir/$_" } readdir($libdir_dh);
-	closedir $libdir_dh;
+        opendir(my $libdir_dh, "$libdir")
+            or syserr(g_('cannot read directory %s: %s'), $libdir, $!);
+        push @files, grep {
+            /(\.so\.|\.so$)/ && -f &&
+            Dpkg::Shlibs::Objdump::is_elf($_);
+        } map { "$libdir/$_" } readdir($libdir_dh);
+        closedir $libdir_dh;
     }
 }
 
-# Merge symbol information
+# Merge symbol information.
 my $od = Dpkg::Shlibs::Objdump->new();
 foreach my $file (@files) {
     debug(1, "Scanning $file for symbol information");
     my $objid = $od->analyze($file);
     unless (defined($objid) && $objid) {
-	warning(g_("Dpkg::Shlibs::Objdump couldn't parse %s\n"), $file);
-	next;
+        warning(g_("Dpkg::Shlibs::Objdump cannot parse %s\n"), $file);
+        next;
     }
     my $object = $od->get_object($objid);
-    if ($object->{SONAME}) { # Objects without soname are of no interest
-	debug(1, "Merging symbols from $file as $object->{SONAME}");
-	if (not $symfile->has_object($object->{SONAME})) {
-	    $symfile->create_object($object->{SONAME}, "$oppackage #MINVER#");
-	}
-	$symfile->merge_symbols($object, $sourceversion);
+    if ($object->{SONAME}) {
+        debug(1, "Merging symbols from $file as $object->{SONAME}");
+        if (not $symfile->has_object($object->{SONAME})) {
+            $symfile->create_object($object->{SONAME}, "$oppackage #MINVER#");
+        }
+        $symfile->merge_symbols($object, $sourceversion);
     } else {
-	debug(1, "File $file doesn't have a soname. Ignoring.");
+        # Objects without soname are of no interest.
+        debug(1, "File $file does not have a soname. Ignoring.");
     }
 }
 $symfile->clear_except(keys %{$od->{objects}});
 
-# Write out symbols files
+# Write out symbols files.
 if ($stdout) {
     $output = g_('<standard output>');
-    $symfile->output(\*STDOUT, package => $oppackage,
-                     template_mode => $template_mode,
-                     with_pattern_matches => $verbose_output,
-                     with_deprecated => $verbose_output);
+    $symfile->output(\*STDOUT,
+        package => $oppackage,
+        template_mode => $template_mode,
+        with_pattern_matches => $verbose_output,
+        with_deprecated => $verbose_output,
+    );
 } else {
     unless (defined($output)) {
-	unless ($symfile->is_empty()) {
-	    $output = "$packagebuilddir/DEBIAN/symbols";
-	    mkdir("$packagebuilddir/DEBIAN") if not -e "$packagebuilddir/DEBIAN";
-	}
+        unless ($symfile->is_empty()) {
+            $output = "$packagebuilddir/DEBIAN/symbols";
+            mkdir("$packagebuilddir/DEBIAN") if not -e "$packagebuilddir/DEBIAN";
+        }
     }
     if (defined($output)) {
-	debug(1, "Storing symbols in $output.");
-	$symfile->save($output, package => $oppackage,
-	               template_mode => $template_mode,
-	               with_pattern_matches => $verbose_output,
-	               with_deprecated => $verbose_output);
+        debug(1, "Storing symbols in $output.");
+        $symfile->save($output,
+            package => $oppackage,
+            template_mode => $template_mode,
+            with_pattern_matches => $verbose_output,
+            with_deprecated => $verbose_output,
+        );
     } else {
-	debug(1, 'No symbol information to store.');
+        debug(1, 'No symbol information to store.');
     }
 }
 
-# Check if generated files differs from reference file
+# Check if generated files differs from reference file.
 my $exitcode = 0;
 
 sub compare_problem
@@ -270,7 +291,7 @@ sub compare_problem
 }
 
 if ($compare || ! $quiet) {
-    # Compare
+    # Compare.
     if (my @libs = $symfile->get_new_libs($ref_symfile)) {
         compare_problem(4, g_('new libraries appeared in the symbols file: %s'), "@libs");
     }
@@ -289,42 +310,49 @@ if ($compare || ! $quiet) {
 
 unless ($quiet) {
     require File::Temp;
-    require Digest::MD5;
+    require File::Compare;
 
     my $file_label;
 
-    # Compare template symbols files before and after
-    my $before = File::Temp->new(TEMPLATE=>'dpkg-gensymbolsXXXXXX');
-    my $after = File::Temp->new(TEMPLATE=>'dpkg-gensymbolsXXXXXX');
-    if ($ref_symfile->{file}) {
-        $file_label = $ref_symfile->{file};
+    # Compare template symbols files before and after.
+    my $before = File::Temp->new(
+        TEMPLATE => 'dpkg-gensymbolsXXXXXX',
+    );
+    my $after = File::Temp->new(
+        TEMPLATE => 'dpkg-gensymbolsXXXXXX',
+    );
+    if ($ref_symfile->{filename}) {
+        $file_label = $ref_symfile->{filename};
     } else {
         $file_label = 'new_symbol_file';
     }
-    $ref_symfile->output($before, package => $oppackage, template_mode => 1);
-    $symfile->output($after, package => $oppackage, template_mode => 1);
+    $ref_symfile->output($before,
+        package => $oppackage,
+        template_mode => 1,
+    );
+    $symfile->output($after,
+        package => $oppackage,
+        template_mode => 1,
+    );
 
     seek $before, 0, 0;
     seek $after, 0, 0;
-    my ($md5_before, $md5_after) = (Digest::MD5->new(), Digest::MD5->new());
-    $md5_before->addfile($before);
-    $md5_after->addfile($after);
 
-    # Output diffs between symbols files if any
-    if ($md5_before->hexdigest() ne $md5_after->hexdigest()) {
-	if (not defined($output)) {
-	    warning(g_('the generated symbols file is empty'));
-	} elsif (defined($ref_symfile->{file})) {
-	    warning(g_("%s doesn't match completely %s"),
-		    $output, $ref_symfile->{file});
-	} else {
-	    warning(g_('no debian/symbols file used as basis for generating %s'),
-		    $output);
-	}
-	my ($a, $b) = ($before->filename, $after->filename);
-	my $diff_label = sprintf('%s (%s_%s_%s)', $file_label, $oppackage,
-	                         $sourceversion, $host_arch);
-	system('diff', '-u', '-L', $diff_label, $a, $b) if find_command('diff');
+    # Output diffs between symbols files if any.
+    if (File::Compare::compare($before, $after) != 0) {
+        if (not defined($output)) {
+            warning(g_('the generated symbols file is empty'));
+        } elsif (defined($ref_symfile->{filename})) {
+            warning(g_('%s does not match completely %s'),
+                    $output, $ref_symfile->{filename});
+        } else {
+            warning(g_('no debian/symbols file used as basis for generating %s'),
+                    $output);
+        }
+        my ($a, $b) = ($before->filename, $after->filename);
+        my $diff_label = sprintf('%s (%s_%s_%s)', $file_label, $oppackage,
+                                 $sourceversion, $host_arch);
+        system('diff', '-u', '-L', $diff_label, $a, $b) if find_command('diff');
     }
 }
 exit($exitcode);
