@@ -19,8 +19,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-use strict;
-use warnings;
+use v5.36;
 
 use Dpkg ();
 use Dpkg::Gettext;
@@ -47,7 +46,8 @@ sub usage {
 'Usage: %s [<option>...]')
     . "\n\n" . g_(
 'Options:
-  -l <changelog-file>      get per-version info from this file.
+  -l, --file <changelog-file>
+                           get per-version info from this file.
   -F <changelog-format>    force changelog format.
   -S, --show-field <field> show the values for <field>.
   -?, --help               show this help message.
@@ -92,9 +92,9 @@ while (@ARGV) {
     } elsif ($arg eq '--reverse') {
         $options{reverse} = 1;
     } elsif ($arg eq '-l' or $arg eq '--file') {
-        $options{file} = shift;
+        $options{filename} = shift;
         usageerr(g_('missing changelog filename'))
-            unless length $options{file};
+            unless length $options{filename};
     } elsif ($arg eq '-S' or $arg eq '--show-field') {
         $fieldname = shift;
     } elsif ($arg eq '-c' or $arg eq '--count' or $arg eq '-n') {
@@ -112,13 +112,15 @@ while (@ARGV) {
         $options{until} = shift;
         ## use critic
     } elsif ($arg eq '--all') {
-	$options{all} = undef;
+        $options{all} = undef;
     } elsif ($arg eq '-?' or $arg eq '--help') {
-	usage(); exit(0);
+        usage();
+        exit 0;
     } elsif ($arg eq '--version') {
-	version(); exit(0);
+        version();
+        exit 0;
     } else {
-	usageerr(g_("unknown option '%s'"), $arg);
+        usageerr(g_("unknown option '%s'"), $arg);
     }
 }
 usageerr(g_('takes no non-option arguments')) if @ARGV;
@@ -128,7 +130,22 @@ my @fields = changelog_parse(%options);
 foreach my $f (@fields) {
     print "\n" if $count++;
     if ($fieldname) {
-        print $f->{$fieldname} . "\n" if exists $f->{$fieldname};
+        next if not exists $f->{$fieldname};
+
+        my ($first_line, @lines) = split /\n/, $f->{$fieldname};
+
+        my $v = '';
+        $v .= $first_line if length $first_line;
+        $v .= "\n";
+        foreach (@lines) {
+            s/\s+$//;
+            if (length == 0 or /^\.+$/) {
+                $v .= ".$_\n";
+            } else {
+                $v .= "$_\n";
+            }
+        }
+        print $v;
     } else {
         print $f->output();
     }
