@@ -119,7 +119,7 @@ show_prompt(const char *cfgfile, const char *realold, const char *realnew,
 
 	/* No --force-confdef but a forcible situation. */
 	/* TODO: check if this condition can not be simplified to
-	 *       just !in_force(FORCE_CONFF_DEF) */
+	 *       just !in_force(FORCE_CONFF_DEF). */
 	if (!(in_force(FORCE_CONFF_DEF) && (what & (CFOF_INSTALL | CFOF_KEEP)))) {
 		if (in_force(FORCE_CONFF_NEW)) {
 			fprintf(stderr,
@@ -239,7 +239,7 @@ spawn_shell(const char *confold, const char *confnew)
 	fputs(" - DPKG_SHELL_REASON\n", stderr);
 	fputs(" - DPKG_CONFFILE_OLD\n", stderr);
 	fputs(" - DPKG_CONFFILE_NEW\n", stderr);
-	fputs(_("Type 'exit' when you're done.\n"), stderr);
+	fputs(_("Type 'exit' when you are done.\n"), stderr);
 
 	pid = subproc_fork();
 	if (!pid) {
@@ -348,7 +348,9 @@ deferred_configure_ghost_conffile(struct pkginfo *pkg, struct conffile *conff)
 	struct pkginfo *otherpkg;
 	struct conffile *otherconff;
 
-	for (otherpkg = &pkg->set->pkg; otherpkg; otherpkg = otherpkg->arch_next) {
+	for (otherpkg = &pkg->set->pkg;
+	     otherpkg;
+	     otherpkg = otherpkg->arch_next) {
 		if (otherpkg == pkg)
 			continue;
 		if (otherpkg->status <= PKG_STAT_HALFCONFIGURED)
@@ -410,7 +412,7 @@ deferred_configure_conffile(struct pkginfo *pkg, struct conffile *conff)
 			deferred_configure_ghost_conffile(pkg, conff);
 			return;
 		}
-		ohshite(_("unable to stat new distributed conffile '%.250s'"),
+		ohshite(_("unable to stat new distributed conffile '%s'"),
 		        cdr_new.buf);
 	}
 	md5hash(pkg, newdisthash, cdr_new.buf);
@@ -420,7 +422,7 @@ deferred_configure_conffile(struct pkginfo *pkg, struct conffile *conff)
 	if (!stat(cdr.buf, &stab))
 		file_copy_perms(cdr.buf, cdr_new.buf);
 	else if (errno != ENOENT)
-		ohshite(_("unable to stat current installed conffile '%.250s'"),
+		ohshite(_("unable to stat current installed conffile '%s'"),
 		        cdr.buf);
 
 	/* Select what to do. */
@@ -430,7 +432,8 @@ deferred_configure_conffile(struct pkginfo *pkg, struct conffile *conff)
 		useredited = -1;
 		distedited = -1;
 		what = CFO_IDENTICAL;
-	} else if (strcmp(currenthash, NONEXISTENTFLAG) == 0 && in_force(FORCE_CONFF_MISS)) {
+	} else if (strcmp(currenthash, NONEXISTENTFLAG) == 0 &&
+		   in_force(FORCE_CONFF_MISS)) {
 		fprintf(stderr,
 		        _("\n"
 		          "Configuration file '%s', does not exist on system.\n"
@@ -463,9 +466,9 @@ deferred_configure_conffile(struct pkginfo *pkg, struct conffile *conff)
 			what |= CFOF_USER_DEL;
 	}
 
-	debug(dbg_conff,
-	      "deferred_configure '%s' (= '%s') useredited=%d distedited=%d what=%o",
-	      usenode->name, cdr.buf, useredited, distedited, what);
+	debug_at(dbg_conff,
+	         "'%s' (= '%s') useredited=%d distedited=%d what=%o",
+	         usenode->name, cdr.buf, useredited, distedited, what);
 
 	what = promptconfaction(pkg, usenode->name, cdr.buf, cdr_new.buf,
 	                        useredited, distedited, what);
@@ -473,35 +476,38 @@ deferred_configure_conffile(struct pkginfo *pkg, struct conffile *conff)
 	switch (what & ~(CFOF_IS_NEW | CFOF_USER_DEL)) {
 	case CFO_KEEP | CFOF_BACKUP:
 		if (unlink(cdr_old.buf) && errno != ENOENT)
-			warning(_("%s: failed to remove old backup '%.250s': %s"),
+			warning(_("%s: failed to remove old backup '%s': %s"),
 			        pkg_name(pkg, pnaw_nonambig), cdr_old.buf,
 			        strerror(errno));
 
 		trig_path_activate(usenode, pkg);
 		if (rename(cdr_new.buf, cdr_dist.buf))
-			warning(_("%s: failed to rename '%.250s' to '%.250s': %s"),
-			        pkg_name(pkg, pnaw_nonambig), cdr_new.buf, cdr_dist.buf,
+			warning(_("%s: failed to rename '%s' to '%s': %s"),
+			        pkg_name(pkg, pnaw_nonambig),
+			        cdr_new.buf, cdr_dist.buf,
 			        strerror(errno));
 		break;
 	case CFO_KEEP:
 		if (unlink(cdr_new.buf))
-			warning(_("%s: failed to remove '%.250s': %s"),
+			warning(_("%s: failed to remove '%s': %s"),
 			        pkg_name(pkg, pnaw_nonambig), cdr_new.buf,
 			        strerror(errno));
 		break;
 	case CFO_INSTALL | CFOF_BACKUP:
 		if (unlink(cdr_dist.buf) && errno != ENOENT)
-			warning(_("%s: failed to remove old distributed version '%.250s': %s"),
-			        pkg_name(pkg, pnaw_nonambig), cdr_dist.buf,
+			warning(_("%s: failed to remove old distributed version '%s': %s"),
+			        pkg_name(pkg, pnaw_nonambig),
+			        cdr_dist.buf,
 			        strerror(errno));
 		if (unlink(cdr_old.buf) && errno != ENOENT)
-			warning(_("%s: failed to remove '%.250s' (before overwrite): %s"),
+			warning(_("%s: failed to remove '%s' (before overwrite): %s"),
 			        pkg_name(pkg, pnaw_nonambig), cdr_old.buf,
 			        strerror(errno));
 		if (!(what & CFOF_USER_DEL))
 			if (link(cdr.buf, cdr_old.buf))
-				warning(_("%s: failed to link '%.250s' to '%.250s': %s"),
-				        pkg_name(pkg, pnaw_nonambig), cdr.buf,
+				warning(_("%s: failed to link '%s' to '%s': %s"),
+				        pkg_name(pkg, pnaw_nonambig),
+				        cdr.buf,
 				        cdr_old.buf, strerror(errno));
 		/* Fall through. */
 	case CFO_INSTALL:
@@ -511,7 +517,7 @@ deferred_configure_conffile(struct pkginfo *pkg, struct conffile *conff)
 	case CFO_NEW_CONFF:
 		trig_path_activate(usenode, pkg);
 		if (rename(cdr_new.buf, cdr.buf))
-			ohshite(_("unable to install '%.250s' as '%.250s'"),
+			ohshite(_("unable to install '%s' as '%s'"),
 			        cdr_new.buf, cdr.buf);
 		break;
 	default:
@@ -544,16 +550,18 @@ deferred_configure(struct pkginfo *pkg)
 		ohshit(_("no package named '%s' is installed, cannot configure"),
 		       pkg_name(pkg, pnaw_nonambig));
 	if (pkg->status == PKG_STAT_INSTALLED)
-		ohshit(_("package %.250s is already installed and configured"),
+		ohshit(_("package %s is already installed and configured"),
 		       pkg_name(pkg, pnaw_nonambig));
 	if (pkg->status != PKG_STAT_UNPACKED &&
 	    pkg->status != PKG_STAT_HALFCONFIGURED)
-		ohshit(_("package %.250s is not ready for configuration\n"
-		         " cannot configure (current status '%.250s')"),
+		ohshit(_("package %s is not ready for configuration\n"
+		         " cannot configure (current status '%s')"),
 		       pkg_name(pkg, pnaw_nonambig),
 		       pkg_status_name(pkg));
 
-	for (otherpkg = &pkg->set->pkg; otherpkg; otherpkg = otherpkg->arch_next) {
+	for (otherpkg = &pkg->set->pkg;
+	     otherpkg;
+	     otherpkg = otherpkg->arch_next) {
 		if (otherpkg == pkg)
 			continue;
 		if (otherpkg->status <= PKG_STAT_CONFIGFILES)
@@ -568,7 +576,7 @@ deferred_configure(struct pkginfo *pkg)
 
 		if (dpkg_version_compare(&pkg->installed.version,
 		                         &otherpkg->installed.version))
-			ohshit(_("package %s %s cannot be configured because "
+			ohshit(_("package %s (%s) cannot be configured because "
 			         "%s is at a different version (%s)"),
 			       pkg_name(pkg, pnaw_always),
 			       versiondescribe(&pkg->installed.version,
@@ -626,7 +634,7 @@ deferred_configure(struct pkginfo *pkg)
 
 	trig_activate_packageprocessing(pkg);
 
-	if (f_noact) {
+	if (!f_act) {
 		pkg_set_status(pkg, PKG_STAT_INSTALLED);
 		ensure_package_clientdata(pkg);
 		pkg->clientdata->istobe = PKG_ISTOBE_NORMAL;
@@ -634,7 +642,7 @@ deferred_configure(struct pkginfo *pkg)
 	}
 
 	if (pkg->status == PKG_STAT_UNPACKED) {
-		debug(dbg_general, "deferred_configure updating conffiles");
+		debug_at(dbg_general, "updating conffiles");
 		/* This will not do at all the right thing with overridden
 		 * conffiles or conffiles that are the ‘target’ of an override;
 		 * all the references here would be to the ‘contested’
@@ -651,7 +659,9 @@ deferred_configure(struct pkginfo *pkg)
 		 * version is in the conffiles data for the package. If
 		 * ‘*.dpkg-new’ no longer exists we assume that we've
 		 * already processed this one. */
-		for (conff = pkg->installed.conffiles; conff; conff = conff->next) {
+		for (conff = pkg->installed.conffiles;
+		     conff;
+		     conff = conff->next) {
 			if (conffile_is_disappearing(conff))
 				continue;
 			deferred_configure_conffile(pkg, conff);
@@ -701,25 +711,25 @@ conffderef(struct pkginfo *pkg, struct varbuf *result, const char *in)
 	loopprotect = 0;
 
 	for (;;) {
-		debug(dbg_conffdetail, "conffderef in='%s' current working='%s'",
-		      in, result->buf);
+		debug_at(dbg_conffdetail, "in='%s' current working='%s'",
+		         in, result->buf);
 		if (lstat(result->buf, &stab)) {
 			if (errno != ENOENT)
 				warning(_("%s: unable to stat config file '%s'\n"
 				          " (= '%s'): %s"),
 				        pkg_name(pkg, pnaw_nonambig), in,
 				        result->buf, strerror(errno));
-			debug(dbg_conffdetail, "conffderef nonexistent");
+			debug_at(dbg_conffdetail, "nonexistent");
 			return 0;
 		} else if (S_ISREG(stab.st_mode)) {
-			debug(dbg_conff, "conffderef in='%s' result='%s'",
+			debug_at(dbg_conff, "in='%s' result='%s'",
 			      in, result->buf);
 			return 0;
 		} else if (S_ISLNK(stab.st_mode)) {
 			ssize_t linksize;
 
-			debug(dbg_conffdetail, "conffderef symlink loopprotect=%d",
-			      loopprotect);
+			debug_at(dbg_conffdetail, "symlink loopprotect=%d",
+			         loopprotect);
 			if (loopprotect++ >= 25) {
 				warning(_("%s: config file '%s' is a circular link\n"
 				          " (= '%s')"),
@@ -728,7 +738,8 @@ conffderef(struct pkginfo *pkg, struct varbuf *result, const char *in)
 				return -1;
 			}
 
-			linksize = file_readlink(result->buf, &target, stab.st_size);
+			linksize = file_readlink(result->buf, &target,
+			                         stab.st_size);
 			if (linksize < 0) {
 				warning(_("%s: unable to readlink conffile '%s'\n"
 				          " (= '%s'): %s"),
@@ -736,7 +747,7 @@ conffderef(struct pkginfo *pkg, struct varbuf *result, const char *in)
 				        result->buf, strerror(errno));
 				return -1;
 			} else if (linksize != stab.st_size) {
-				warning(_("symbolic link '%.250s' size has "
+				warning(_("symbolic link '%s' size has "
 				          "changed from %jd to %zd"),
 				        result->buf, (intmax_t)stab.st_size,
 				        linksize);
@@ -746,21 +757,21 @@ conffderef(struct pkginfo *pkg, struct varbuf *result, const char *in)
 					return -1;
 			}
 
-			debug(dbg_conffdetail,
-			      "conffderef readlink gave %zd, '%s'",
-			      linksize, target.buf);
+			debug_at(dbg_conffdetail, "readlink gave %zd, '%s'",
+			         linksize, target.buf);
 
 			if (target.buf[0] == '/') {
 				varbuf_set_str(result, dpkg_fsys_get_dir());
-				debug(dbg_conffdetail,
-				      "conffderef readlink absolute");
+				debug_at(dbg_conffdetail, "readlink absolute");
 			} else {
 				ssize_t r;
 
-				for (r = result->used - 1; r > 0 && result->buf[r] != '/'; r--)
+				for (r = result->used - 1;
+				     r > 0 && result->buf[r] != '/';
+				     r--)
 					;
 				if (r < 0) {
-					warning(_("%s: conffile '%.250s' resolves to degenerate filename\n"
+					warning(_("%s: conffile '%s' resolves to degenerate filename\n"
 					          " ('%s' is a symlink to '%s')"),
 					        pkg_name(pkg, pnaw_nonambig),
 					        in, result->buf, target.buf);
@@ -769,13 +780,13 @@ conffderef(struct pkginfo *pkg, struct varbuf *result, const char *in)
 				if (result->buf[r] == '/')
 					r++;
 				varbuf_trunc(result, r);
-				debug(dbg_conffdetail,
-				      "conffderef readlink relative to '%s'",
-				      varbuf_str(result));
+				debug_at(dbg_conffdetail,
+				         "readlink relative to '%s'",
+				         varbuf_str(result));
 			}
 			varbuf_add_varbuf(result, &target);
 		} else {
-			warning(_("%s: conffile '%.250s' is not a plain file or symlink (= '%s')"),
+			warning(_("%s: conffile '%s' is not a plain file or symlink (= '%s')"),
 			        pkg_name(pkg, pnaw_nonambig), in, result->buf);
 			return -1;
 		}
